<?php

    

/*
* $Id: zipur_toolbox.php
* $Loc: /admin/
*
* Name: zipurToolbox
* Version: 0.2.0
* Release Date: 08/09/2020
* Author: Preston Lord
* 	 aka zipurman / zipur.ca / plord@inetx.ca
*
* License: Released under the GNU General Public License
*
* Comments: Copyright (c) 2020: Preston Lord - @zipurman - Intricate Networks Inc.
* 
* 
*   Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
* 
*   1. Re-distributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
* 
*   2. Re-distributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
* 
*   3. Neither the name of the copyright holder nor the names of its contributors may be used to endorse or promote products derived from this software without specific prior written permission.
* 
*   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
* (Packaged with zipurUpdater v0.2.0)
*/





    require 'includes/application_top.php';

    /** Get a folder to download as a zip
     *
     * @param $directorytoget
     * @param $versiontag
     */
    function zipGetZip( $directorytoget ) {

        global $updatesBaseDirectory;

        $dir            = $updatesBaseDirectory . $directorytoget;
        $zip_file       = $directorytoget . '.zip';
        $zip_file_w_tag = $directorytoget . '_zip.zip';
        $rootPath       = realpath( $dir );
        $zip            = new ZipArchive();
        $zip->open( $updatesBaseDirectory . $zip_file_w_tag, ZipArchive::CREATE | ZipArchive::OVERWRITE );
        // Create recursive directory iterator
        /** @var SplFileInfo[] $files */
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator( $rootPath ),
            RecursiveIteratorIterator::LEAVES_ONLY
        );
        foreach ( $files as $name => $file ) {
            //directories added automatically
            if ( ! $file->isDir() ) {
                // Get real and relative path for current file
                $filePath     = $file->getRealPath();
                $relativePath = substr( $filePath, strlen( $rootPath ) + 1 );
                // Add current file to archive
                $zip->addFile( $filePath, $relativePath );
            }
        }
        // Zip archive will be created only after closing object
        $zip->close();
        header( 'Content-Description: File Transfer' );
        header( 'Content-Type: application/octet-stream' );
        header( 'Content-Disposition: attachment; filename=' . basename( $updatesBaseDirectory . $zip_file ) );
        header( 'Content-Transfer-Encoding: binary' );
        header( 'Expires: 0' );
        header( 'Cache-Control: must-revalidate' );
        header( 'Pragma: public' );
        header( 'Content-Length: ' . filesize( $updatesBaseDirectory . $zip_file_w_tag ) );
        ob_clean();
        ob_end_flush();
        readfile( $updatesBaseDirectory . $zip_file_w_tag );
    }

    $zipur_updater_config = [
        'creator_active'             => true,
        'version_file_report_active' => true,
    ];

    require 'includes/functions/zipur_toolbox.php';

    $zipUpdaterVersion = zipGetFileVersion(basename( __FILE__ ) );
    $version              = tep_get_version();
    $osprod               = ( zipCheckIfPhoenix() ) ? 'CE Phoenix' : 'OS Commerce';
    $customadminpath      = basename( DIR_FS_ADMIN );
    $installedfiles       = [];
    $cleancorefiles       = [];
    $zip_added_files      = [];
    $zip_altered_files    = [];
    $zip_missing_files    = [];
    $updatesBaseDirectory = DIR_FS_ADMIN . 'updates/';

    $zipedit             = zipVarCheck( "zipedit", '' );
    $zipzip              = zipVarCheck( "zipzip", '' );
    $updatebuildstep     = zipVarCheck( "updatebuildstep", 0, "FILTER_VALIDATE_INT", 0 );
    $updatefolder        = zipVarCheck( "updatefolder", '' );
    $zipinstall          = zipVarCheck( "zipinstall", '' );
    $zipdelete           = zipVarCheck( "zipdelete", '' );
    $zipremove           = zipVarCheck( "zipremove", '' );
    $deletecleancore     = zipVarCheck( "deletecleancore", '' );
    $zipupdatecreator    = zipVarCheck( "zipupdatecreator", 0, "FILTER_VALIDATE_INT", 0 );
    $zipupdatedownloader = zipVarCheck( "zipupdatedownloader", 0, "FILTER_VALIDATE_INT", 0 );
    $installstep         = zipVarCheck( "installstep", 1, "FILTER_VALIDATE_INT", 1 );
    $zipreport           = zipVarCheck( "zipreport", 0, "FILTER_VALIDATE_INT", 0 );
    $versiondownload     = zipVarCheck( "versiondownload", 0, "FILTER_VALIDATE_INT", 0 );
    $downloadpackagenow  = zipVarCheck( "downloadpackagenow", '' );

    if ( ! empty( $downloadpackagenow ) ) {
        $filedata = file_get_contents( 'https://zipur.ca/osc/pkgs/files/' . $downloadpackagenow );
        $downloadfile = fopen( $updatesBaseDirectory . $downloadpackagenow, "w" ) or die( TEXT_UPDATES_FILE_UPDATE_CREATE_FAILED );
        fwrite( $downloadfile, $filedata );
        fclose( $downloadfile );

        $zip = new ZipArchive;
        $res = $zip->open( $updatesBaseDirectory . $downloadpackagenow );
        if ( $res === true ) {
            $downloadpackagenowfolder = str_replace( '.zip', '', $downloadpackagenow );

            $zip->extractTo( $updatesBaseDirectory . $downloadpackagenowfolder );
            $zip->close();
            unlink( $updatesBaseDirectory . $downloadpackagenow );//deletes downloaded zip
        } else {
            echo '<br/><span class="text-danger">' . TEXT_THIS_FILE_REPORT_UNZIP_FAILED . ' (' . $downloadfile . ')</span>';
        }

    }

    if ( ! empty( $zipzip ) ) {
        $ziphash = hash( 'sha256', $updatefolder );
        if ( $ziphash == $zipzip ) {
            zipGetZip( $updatefolder );
        }
    }

    require 'includes/template_top.php';

?>
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/css/select2.min.css" rel="stylesheet"/>
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-beta.1/dist/js/select2.min.js"></script>
<?php

    zipOscCss();

    if ( empty( $zipur_updater_config['creator_active'] ) ) {
        $zipupdatecreator = 0;
    }
    if ( empty( $zipur_updater_config['version_file_report_active'] ) ) {
        $zipreport = 0;
    }

    /** Will loop through a directory root and delete all files - be careful !!
     * Taken from example https://paulund.co.uk/php-delete-directory-and-files-in-directory
     *
     * @param $dirname
     *
     * @return bool
     */
    function zipDeleteDirectory( $dirname ) {

        if ( is_dir( $dirname ) ) {
            $dir_handle = opendir( $dirname );
        }
        if ( ! $dir_handle ) {
            return false;
        }
        /** @noinspection PhpAssignmentInConditionInspection */
        while ( $file = readdir( $dir_handle ) ) {
            if ( $file != "." && $file != ".." ) {
                if ( ! is_dir( $dirname . "/" . $file ) ) {
                    unlink( $dirname . "/" . $file );
                } else {
                    zipDeleteDirectory( $dirname . '/' . $file );
                }
            }
        }
        closedir( $dir_handle );
        rmdir( $dirname );

        return true;
    }

    /**
     * Loop through files and update as needed
     *
     * @param        $path
     * @param string $buildpath
     * @param int    $level
     * @param string $thisfolder
     * @param int    $installthis
     * @param string $folder
     */
    function zipur_loop_files( $path, $buildpath = '', $level = - 1, $thisfolder = '', $installthis = 0, $folder = '' ) {

        global $customadminpath, $updatesBaseDirectory;

        $protectedfiles = [ 'update.php', 'phoenix.sql', 'install' ];

        $level ++;
        $buildpath .= $thisfolder;
        $buildpath .= ( ! empty( $thisfolder ) ) ? '/' : '';
        $buildpath = str_replace( DIR_FS_ADMIN . 'updates', '', $buildpath );

        exec( 'ls ' . $path, $files );

        foreach ( $files as $file ) {

            if ( ( in_array( basename( $file ), $protectedfiles ) ) && $level == 0 ) {
                //do nothing
            } else {

                $buildpath2 = preg_replace( '/^admin/', $customadminpath . '', $buildpath, 1 );
                $file2      = ( $file == 'admin' && $level == 0 ) ? $customadminpath : $file;

                if ( ! empty( $installthis ) ) {
                    $copyfrom = $updatesBaseDirectory . $folder . '/' . $buildpath . $file;
                    $copyto   = DIR_FS_CATALOG . $buildpath2 . $file2;
                }
                $note = '';
                if ( is_dir( $path . '/' . $file ) ) {
                    //make sure folder is created
                    if ( $installthis == 1 ) {
                        if ( ! file_exists( $copyto ) ) {
                            if ( ! mkdir( $copyto, 0700 ) ) {
                                $note = '<span class="text-danger">' . TEXT_UPDATES_MAKE_NEW_FOLDER_FAIL . ': ' . $copyto . '</span>';
                            } else {
                                $note = '<span class="text-success">' . TEXT_UPDATES_MAKE_NEW_FOLDER . ': ' . $copyto . '</span>';
                            }
                        } else {
                            $note = '<span class="text-success">' . TEXT_UPDATES_FOLDER_EXISTS . ': ' . $copyto . '</span>';
                        }
                    }

                    zipurRow( '<small>' . $buildpath . $file . '</small>', '<small>' . $buildpath2 . $file2 . '</small>', '<small>' . $note . '</small>', '', '', 'text-info p1' );

                    zipur_loop_files( $path . '/' . $file, $buildpath, $level, $file, $installthis, $folder );

                } else {

                    if ( ! empty( $installthis ) ) {
                        if ( $installthis == 1 ) {
                            //if file size is empty - delete file
                            $filesize = filesize( $copyfrom );
                            if ( empty( $filesize ) ) {
                                if ( file_exists( $copyto ) ) {
                                    if ( ! unlink( $copyto ) ) {
                                        $note = '<span class="text-danger">' . TEXT_UPDATES_FILE_DELETE_FAILED . ': ' . $copyto . '</span>';
                                    } else {
                                        $note = '<span class="text-success">' . TEXT_UPDATES_FILE_DELETED . ': ' . $copyto . '</span>';
                                    }
                                } else {
                                    $note = '<span class="text-success">' . TEXT_UPDATES_FILE_ALREADY_DELETED . ': ' . $copyto . '</span>';
                                }
                            } else {
                                if ( ! copy( $copyfrom, $copyto ) ) {
                                    $note = '<span class="text-danger">' . TEXT_UPDATES_FILE_COPY_FAIL . ':<br/>' . TEXT_UPDATES_FILE_FROM . ': ' . $copyfrom . '<br/>' . TEXT_UPDATES_FILE_TO . ': ' . $copyto . '</span>';
                                } else {
                                    $note = '<span class="text-success">' . TEXT_UPDATES_FILE_COPIED . ': ' . $copyto . '</span>';
                                }
                            }
                        }
                    }
                    zipurRow( '<small>' . $buildpath . $file . '</small>', '<small>' . $buildpath2 . $file2 . '</small>', '<small>' . $note . '</small>', '', '', 'text-info p1' );
                }
            }
        }
    }

    /**
     *  Save some code by generating table rows dynamically
     *
     * @param string $col1
     * @param string $col2
     * @param string $col3
     * @param string $col4
     * @param string $col5
     * @param string $rowclass
     */
    function zipurRow( $col1 = '', $col2 = '', $col3 = '', $col4 = '', $col5 = '', $rowclass = '' ) {

        echo <<<row
        <tr class="{$rowclass}">
            <td>{$col1}</td>
            <td>{$col2}</td>
            <td>{$col3}</td>
            <td>{$col4}</td>
            <td class="text-right">{$col5}</td>
        </tr>
        row;
    }

    /**
     * Create outline for update actions
     *
     * @param        $itemlist
     *
     * @param bool   $proceed
     *
     * @param string $optionaltype
     *
     * @return string
     */
    function zipShowUpdateOutline( $itemlist, $proceed = false, $optionaltype = '' ) {

        global $customadminpath;
        $message = '';
        $js      = '';

        if ( empty( $itemlist ) ) {
            $message .= ' (None)' . PHP_EOL;
        } else {
            $message   .= '<ol>' . PHP_EOL;
            $itemcount = 0;
            foreach ( $itemlist as $item ) {
                $itemcount ++;
                $action           = '';
                $zipoptionalcheck = zipVarCheck( "zipoptional{$optionaltype}{$itemcount}", 0 );

                if ( $item['type'] == 'ajax' ) {
                    $action = $item['action'];
                    if ( ! $proceed ) {
                        $action .= ( empty( $item['optional'] ) ) ? '' : ' (' . TEXT_THIS_UPDATE_OPTIONAL . ')' . '<select name="zipoptional' . $optionaltype . $itemcount . '"><option value="0">' . TEXT_UPDATES_ACTION_PROCEED . '</option><option value="1">' . TEXT_UPDATES_ACTION_SKIP . '</option></select>';
                    }
                    foreach ( $item['items'] as $actionitem ) {
                        $action      .= '<br/>(' . $actionitem . ') ';
                        $actionarray = explode( '/', $actionitem );
                        if ( $proceed && empty( $zipoptionalcheck ) ) {
                            $js     .= <<<js
                        zip_module_update('{$actionarray[0]}.php', '{$actionarray[1]}', '{$actionarray[2]}', '{$item['action']}');
                        js;
                            $action .= ' <i class="fas fa-check text-success"></i>';
                        } else if ( $proceed && ! empty( $zipoptionalcheck ) ) {
                            $action .= ' <i class="fas fa-exclamation text-warning"></i> SKIPPED';
                        }
                    }
                } else if ( $item['type'] == 'files_delete' ) {
                    if ( $proceed && empty( $zipoptionalcheck ) ) {
                        foreach ( $item['items'] as $actionitem ) {
                            $actionitem = preg_replace( '/^\/admin/', '/' . $customadminpath, $actionitem, 1 );
                            if ( file_exists( DIR_FS_CATALOG . $actionitem ) ) {
                                unlink( DIR_FS_CATALOG . $actionitem );
                            }
                            $action .= TEXT_UPDATES_ACTION_REMOVE . ' ' . $actionitem . ' <i class="fas fa-check text-success"></i><br/>';
                        }

                    } else if ( $proceed && ! empty( $zipoptionalcheck ) ) {
                        $action = '<i class="fas fa-exclamation text-warning"></i> SKIPPED - SQL: ' . TEXT_UPDATES_DELETE;
                    } else {
                        $action = TEXT_UPDATES_DELETE . ': ';
                        $action .= ( empty( $item['optional'] ) ) ? '' : ' (' . TEXT_THIS_UPDATE_OPTIONAL . ')' . '<select name="zipoptional' . $optionaltype . $itemcount . '"><option value="0">' . TEXT_UPDATES_ACTION_PROCEED . '</option><option value="1">' . TEXT_UPDATES_ACTION_SKIP . '</option></select>';
                        foreach ( $item['items'] as $actionitem ) {
                            $actionitem = preg_replace( '/^\/admin/', '/' . $customadminpath, $actionitem, 1 );
                            $action     .= TEXT_UPDATES_ACTION_REMOVE . ' ' . $actionitem . '<br/>';
                        }

                    }
                } else if ( $item['type'] == 'sql' ) {
                    foreach ( $item['items'] as $it ) {
                        $action = 'SQL: ' . substr( $it, 0, 30 ) . '...';
                    }
                    if ( ! $proceed ) {
                        $action .= ( empty( $item['optional'] ) ) ? '' : ' (' . TEXT_THIS_UPDATE_OPTIONAL . ')' . '<select name="zipoptional' . $optionaltype . $itemcount . '"><option value="0">' . TEXT_UPDATES_ACTION_PROCEED . '</option><option value="1">' . TEXT_UPDATES_ACTION_SKIP . '</option></select>';
                    }
                    if ( $proceed && empty( $zipoptionalcheck ) ) {
                        foreach ( $item['items'] as $actionitem ) {
                            $actionarray = explode( ';', $actionitem );
                            foreach ( $actionarray as $queryitem ) {
                                if ( ! empty( $queryitem ) ) {
                                    if ( strlen( $queryitem ) > 5 ) {
                                        zip_db_query( $queryitem );
                                    }
                                }
                            }
                        }
                        $action .= ' <i class="fas fa-check text-success"></i>';
                    } else if ( $proceed && ! empty( $zipoptionalcheck ) ) {
                        foreach ( $item['items'] as $it ) {
                            $action = '<i class="fas fa-exclamation text-warning"></i> ' . TEXT_UPDATES_ACTION_SKIP . ' - SQL: ' . substr( $it, 0, 30 ) . '...';
                        }

                    }
                }
                $message .= '<li>' . $action . '</li>' . PHP_EOL;
            }
            $message .= '</ol>' . PHP_EOL;
            $message .= '<input type="hidden" name="zipitemcount' . $optionaltype . '" value="' . $itemcount . '">' . PHP_EOL;
        }

        if ( ! empty( $js ) ) {
            $message .= <<<js
            <script>
            {$js}
            </script>
            js;
        }

        return $message;
    }

    /**
     * Calc file array to show in dropdown
     */
    function zipUpdaterFileBuilder() {

        global $installedfiles, $updatesBaseDirectory, $updatefolder, $customadminpath;

        zipGetDirArray( DIR_FS_CATALOG, [
            'images',
            'updates',
            'old',
            'install',
            'clean_core',
            'README',
            'README.md',
        ], 0, true );
        $selectinstalledfiles = $installedfiles;
        $installedfiles       = [];

        $thisfolder = $updatesBaseDirectory . '' . $updatefolder;

        if ( ! empty( $updatefolder ) ) {
            zipGetDirArray( $thisfolder, [ 'update.php' ], 0, true );
        }

        ?>
        <h4 class="text-light bg-dark p-2"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_FILES_HEADER; ?></h4>
        <table class="table" style="font-size: 0.8rem;">
            <tbody>
            <tr>
                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_FILES_CHOOSE; ?>:</td>
                <td class="col-md-7">
                    <select name="empty_files" class="select2">
                        <?php
                            foreach ( $selectinstalledfiles as $key => $installedfile ) {
                                echo '<option value="' . $key . '">' . $key . '</option>' . PHP_EOL;
                            }
                        ?>
                    </select>
                    <a class="btn btn-sm btn-outline-secondary"
                       href="javascript: zip_add_file();"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_ADD_FILE; ?></a>
                </td>
                <td class="col-md-3"></td>
            </tr>
            <tr>
                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_FILES; ?>:</td>
                <td class="col-md-7">
                    <textarea rows="3" cols="100"
                              id="update_install_files" name="update_install_files"><?php
                            $filecount = 0;
                            foreach ( $installedfiles as $key => $installedfile ) {
                                $filecount ++;
                                $key = preg_replace( '/^' . $customadminpath . '\/updates\/' . $updatefolder . '/', '', $key, 1 );
                                echo $key;
                                if ( $filecount < count( $installedfiles ) ) {
                                    echo PHP_EOL;
                                }
                            }
                        ?></textarea>
                </td>
                <td class="col-md-3"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_THESE_FILES; ?></td>
            </tr>
            </tbody>
        </table>
        <script>
            $(function () {
                $('.select2').select2();
            });
        </script>
        <?php
    }

    /**
     * Generate outline for actions on updates
     *
     * @param $actions
     * @param $title
     * @param $varset
     */
    function zipUpdaterActionBuilder( $actions, $title, $varset ) {

        ?>
        <h4 class="text-light bg-dark p-2"><?php echo $title; ?></h4>
        <a class="btn btn-sm btn-outline-secondary"
           href="javascript: zip_add_action('<?php echo $varset; ?>');"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_ADD_ACTION; ?></a>
        <table class="table" style="font-size: 0.8rem;">
            <tbody id="update_<?php echo $varset; ?>_action_area">
            <?php
                $actions[] = [
                    'hidden'   => true,
                    'type'     => 'ajax',
                    'action'   => 'install',
                    'optional' => true,
                    'items'    => [],
                ];
                if ( empty( $actions ) ) {
                    ?>
                    <tr class="update_<?php echo $varset; ?>_actions_none">
                        <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_TASKS; ?>:</td>
                        <td class="col-md-10"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_NONE; ?></td>
                    </tr>
                    <?php
                }
                foreach ( $actions as $action ) {

                    $itemtext = '';
                    $itemtip  = '';
                    if ( $action['type'] == 'ajax' ) {
                        foreach ( $action['items'] as $item ) {
                            $itemtext .= ( ! empty( $itemtext ) ) ? "\n" : '';
                            $itemtext .= $item;
                        }
                        $itemtip = TEXT_THIS_FILE_UPDATE_CREATOR_AJAX_TIP;
                    } else if ( $action['type'] == 'sql' ) {
                        $itemtext = '';
                        foreach ( $action['items'] as $it ) {
                            $itemtext .= $it;
                        }
                        $itemtip = TEXT_THIS_FILE_UPDATE_CREATOR_SQL_TIP;
                    } else if ( $action['type'] == 'files_delete' ) {
                        foreach ( $action['items'] as $item ) {
                            $itemtext .= ( ! empty( $itemtext ) ) ? "\n" : '';
                            $itemtext .= $item;
                        }
                        $itemtip = TEXT_THIS_FILE_UPDATE_CREATOR_FILE_DELETE_TIP;
                    }

                    $rowstyle = ( ! empty( $action['hidden'] ) ) ? 'display: none;' : '';
                    $rowid    = ( ! empty( $action['hidden'] ) ) ? ' id="update_' . $varset . '_action_blank_row" ' : '';

                    ?>
                    <tr style="<?php echo $rowstyle; ?>" <?php echo $rowid; ?>>
                        <td class="col-md-1 text-right"><i
                                    class="fas fa-trash-alt text-danger zip_update_delete_action"></i> <?php echo TEXT_THIS_FILE_UPDATE_CREATOR_ACTION; ?>
                            :
                        </td>
                        <td class="col-md-1">
                            <select class="zip_update_action_type" name="update_<?php echo $varset; ?>_action_type[]"
                                    onChange="">
                                <option value="ajax" <?php if ( $action['type'] == 'ajax' ) {
                                    echo 'SELECTED';
                                } ?>>ajax
                                </option>
                                <option value="sql" <?php if ( $action['type'] == 'sql' ) {
                                    echo 'SELECTED';
                                } ?>>sql
                                </option>
                                <option value="files_delete" <?php if ( $action['type'] == 'files_delete' ) {
                                    echo 'SELECTED';
                                } ?>><?php echo TEXT_UPDATES_ACTION_FILES_DELETE; ?>
                                </option>
                            </select>
                        </td>
                        <td class="col-md-1">
                            <select name="update_<?php echo $varset; ?>_action_action[]">
                                <option value="install" <?php if ( $action['action'] == 'install' ) {
                                    echo 'SELECTED';
                                } ?>><?php echo TEXT_UPDATES_ACTION_INSTALL; ?>
                                </option>
                                <option value="remove" <?php if ( $action['action'] == 'remove' ) {
                                    echo 'SELECTED';
                                } ?>><?php echo TEXT_UPDATES_ACTION_REMOVE; ?>
                                </option>
                            </select>
                        </td>
                        <td class="col-md-1">
                            <select name="update_<?php echo $varset; ?>_action_optional[]">
                                <option value="true" <?php if ( $action['optional'] ) {
                                    echo 'SELECTED';
                                } ?>><?php echo TEXT_THIS_UPDATE_OPTIONAL; ?>
                                </option>
                                <option value="false" <?php if ( ! $action['optional'] ) {
                                    echo 'SELECTED';
                                } ?>><?php echo TEXT_THIS_UPDATE_REQUIRED; ?>
                                </option>
                            </select>
                        </td>
                        <td class="col-md-5"><textarea rows="3" cols="60"
                                                       name="update_<?php echo $varset; ?>_action_items[]"><?php echo $itemtext; ?></textarea>
                        </td>
                        <td class="col-md-3">
                            <?php echo $itemtip; ?>
                        </td>
                    </tr>
                    <?php
                }
            ?>
            </tbody>
        </table>
        <?php
    }

    if ( ! empty( $deletecleancore ) ) {
        exec( 'ls ' . DIR_FS_ADMIN . 'clean_core/', $cleancorefileitemstodelete );
        if ( ! empty( $cleancorefileitemstodelete ) ) {
            foreach ( $cleancorefileitemstodelete as $cleancorefileitemstodeleteitem ) {
                $thisdeletecleancoreitem = DIR_FS_ADMIN . 'clean_core/' . $cleancorefileitemstodeleteitem;
                $deletehash              = hash( 'sha256', $thisdeletecleancoreitem );
                if ( $deletecleancore == $deletehash ) {
                    zipDeleteDirectory( $thisdeletecleancoreitem );
                }
            }
        }
    }

?>

<h1 class="display-4 mb-2"><?php echo HEADING_TITLE . ' (' . $zipUpdaterVersion . ')'; ?></h1>
<?php zipAdBanner(); ?>
<h4 class="display-8 mb-2"><?php echo '(' . $osprod . ' ' . TEXT_UPDATES_FILE_LIBRARY_VERSION . ' ' . $version . ')'; ?></h4>
<hr/>

<nav class="navbar navbar-light bg-light">
    <a class="navbar-brand btn btn-sm btn-outline-secondary"
       href="zipur_toolbox.php"><?php echo TEXT_THIS_MENU_UPDATER; ?></a>
    <a class="navbar-brand btn btn-sm btn-outline-secondary"
       href="zipur_toolbox.php?zipupdatedownloader=1"><?php echo TEXT_THIS_MENU_UPDATE_DOWNLOAD; ?></a>
    <?php
        if ( ! empty( $zipur_updater_config['creator_active'] ) ) {
            ?>
            <a class="navbar-brand btn btn-sm btn-outline-secondary"
               href="zipur_toolbox.php?zipupdatecreator=1"><?php echo TEXT_THIS_MENU_UPDATE_CREATOR; ?></a>
            <?php
        }
        if ( ! empty( $zipur_updater_config['version_file_report_active'] ) ) {
            ?>
            <a class="navbar-brand btn btn-sm btn-outline-secondary"
               href="zipur_toolbox.php?zipreport=1"><?php echo TEXT_THIS_MENU_REPORT; ?></a>
            <?php
        }
    ?>
</nav>

<hr/>

<?php
    if ( ! empty( $zipupdatedownloader ) ) {
        
        $requestfrom = ( ! defined( HTTPS_SERVER ) ) ? HTTP_SERVER : HTTPS_SERVER;

        $content = file_get_contents( "https://zipur.ca/osc/pkgs/?requestfrom=" . $requestfrom );
        $data    = json_decode( $content );

        echo '<div class="table-responsive">';
        foreach ( $data as $key => $datum ) {
            echo '<h4 class="text-primary">' . $key . '</h4>';

            foreach ( $datum as $key2 => $datum2 ) {
                echo '<hr/><h5 class="m-2">' . $key2 . '</h5><hr/>';
                echo '<div class="row">';
                foreach ( $datum2 as $key3 => $datum3 ) {

                    if ( ! empty( $datum3->activeyn ) ) {

                        $osc_versionstatus     = [ 0 ];
                        $phoenix_versionstatus = [ 0 ];
                        $okaymyversion = 0;
                        if ( ! zipCheckIfPhoenix() && !empty($datum3->supports_osc )) {
                            $osc_versionstatus = zipCheckUpdateVersion( $datum3->requires_osc, $version );
                            $okaymyversion = $osc_versionstatus[0];
                        } else if ( zipCheckIfPhoenix() &&  !empty($datum3->supports_phoenix )) {
                            $phoenix_versionstatus = zipCheckUpdateVersion( $datum3->requires_phoenix, $version );
                            $okaymyversion = $phoenix_versionstatus[0];
                        }

                        if ( ! empty( $datum3->release_date ) ) {
                            $since_start = date_diff( date_create( $datum3->release_date ), date_create() );
                            $days        = $since_start->days;
                            $days        += round( $since_start->h / 24, 0 );

                            if ( $days <= 1 ) {
                                $datum3->release_date .= ' <span class="text-success">(' . TEXT_UPDATES_FILE_LIBRARY_TODAY . ')</span>';
                            } else if ( $days <= 2 ) {
                                $datum3->release_date .= ' <span class="text-success">(' . TEXT_UPDATES_FILE_LIBRARY_YESTERDAY . ')</span>';
                            } else if ( $days <= 7 ) {
                                $datum3->release_date .= ' <span class="text-warning">(' . $days . ' ' . TEXT_UPDATES_FILE_LIBRARY_DAYS_AGO . ')</span>';
                            } else if ( $days <= 56 ) {
                                $weeks                = round( $days / 7 );
                                $datum3->release_date .= ' <span class="text-secondary">(' . $weeks . ' ' . TEXT_UPDATES_FILE_LIBRARY_WEEKS_AGO . ')</span>';
                            }
                        }

                        ?>
                        <div class="col-md-3 mb-4">
                            <div class="card h-100">
                                <div class="zip_download_package_header bg-dark text-light p-2 rounded-top"
                                     style="position: relative; ">
                                    <?php
                                        echo $datum3->name;

                                        if ( ! empty( $datum3->settings_file ) ) {
                                            if ( file_exists( DIR_FS_ADMIN . $datum3->settings_file ) ) {
                                                echo '<a href="' . $datum3->settings_file . '" class="btn  btn-info btn-sm float-right mr-1" style="font-size: 0.5rem;"><i class="fas fa-cogs"></i> ' . TEXT_UPDATES_FILE_LIBRARY_SETTINGS . '</a>';
                                            }
                                        }

                                    ?>
                                </div>
                                <div class="bg-light border-bottom" style="height: 80px; <?php
                                    if ( ! empty( $datum3->bgimage ) ) {
                                        echo 'background: url(\'' . $datum3->bgimage . '\'); background-size: cover; background-repeat: no-repeat;';
                                    }
                                    if ( ! empty( $datum3->bgimagepos ) ) {
                                        echo 'background-position: ' . $datum3->bgimagepos . '; background-size: cover; background-repeat: no-repeat;';
                                    }
                                ?>">

                                </div>

                                <div class="card-body">

                                    <p class="card-text"
                                       style="overflow: hidden; white-space: nowrap; text-overflow: ellipsis; font-weight: 600;">
                                        <small class="text-muted"><?php echo TEXT_UPDATES_FILE_LIBRARY_VERSION . ': ' . $datum3->version; ?></small>
                                        <?php
                                            if ( ! empty( $datum3->checkfile ) ) {
                                                $checkfile = $datum3->checkfile;
                                                $checkfile = preg_replace( '/^admin\//', $customadminpath . '/', $checkfile, 1 );
                                                $checkfile = DIR_FS_CATALOG . $checkfile;
                                                if ( file_exists( $checkfile ) ) {

                                                    $vertext       = '';
                                                    $getcheckfile  = file_get_contents( $checkfile );
                                                    $checkstartloc = strpos( $getcheckfile, 'Version' );
                                                    $checkendloc   = strpos( $getcheckfile, "\n", $checkstartloc );
                                                    if ( ( $checkendloc - $checkstartloc ) < 30 ) {
                                                        $versiontext = substr( $getcheckfile, $checkstartloc, $checkendloc - $checkstartloc + 2 );
                                                        $versiontext = preg_replace( '/[^0-9.]/', '', $versiontext );
                                                        $verok       = zipCheckNeedsUpdateVersion( $versiontext, $datum3->version );
                                                        if ( empty( $verok ) ) {
                                                            echo '<a href="zipur_toolbox.php?downloadpackagenow=' . $datum3->file . '" class="btn  btn-warning btn-sm float-right mr-1" style="font-size: 0.5rem;"><i class="fas fa-sync-alt"></i> ' . TEXT_UPDATES_FILE_LIBRARY_UPDATE_NOW . '</a>';
                                                            $vertext = '(Ver.' . $versiontext . ')';
                                                        }
                                                    }

                                                    echo '<span class="btn  btn-success btn-sm float-right mr-1" style="font-size: 0.5rem;">' . TEXT_UPDATES_FILE_LIBRARY_INSTALLED . ' ' . $vertext . '</span>';
                                                    echo '<a href="zipur_toolbox.php" class="btn  btn-secondary btn-sm float-right mr-1" style="font-size: 0.5rem;"><i class="fas fa-trash"></i> ' . TEXT_UPDATES_ACTION_REMOVE . '</a>';

                                                } else if ( ! empty( $datum3->file ) && !empty($okaymyversion)) {

                                                    echo '<a href="zipur_toolbox.php?downloadpackagenow=' . $datum3->file . '" class="btn btn-info btn-sm float-right text-light" style="font-size: 0.5rem;"><i class="fas fa-cloud-download-alt"></i> ' . TEXT_UPDATES_FILE_LIBRARY_DOWNLOAD . '</a>';
                                                } else if ( ! empty( $datum3->file ) && empty($okaymyversion)) {

                                                    echo '<small class="text-warning float-right mr-1"><i class="fas fa-exclamation-circle"></i> ' . TEXT_UPDATES_FILE_LIBRARY_NOT_SUPPORTED . '</small>';
                                                }
                                            }
                                        ?>

                                    </p>

                                    <p class="card-text" style="word-wrap: break-word;font-size: 0.8rem;">
                                        <?php echo $datum3->desc; ?>
                                    </p>

                                    <p class="card-text">

                                        <small class="text-muted"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_AUTHOR . ': ' . $datum3->author; ?></small><br/>
                                        <small class="text-muted"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_DATE . ': ' . $datum3->release_date; ?></small>
                                        <?php
                                            if ( ! empty( $datum3->more ) ) {
                                                ?>
                                                <small class="text-muted float-right"><a
                                                            href="<?php echo $datum3->more; ?>"
                                                            target="_blank"><?php echo TEXT_UPDATES_FILE_LIBRARY_MORE; ?></a></small>
                                                <?php
                                            }
                                        ?>
                                    </p>
                                    <div>
                                        <small>
                                            <?php echo TEXT_UPDATES_FILE_LIBRARY_SUPPORTS; ?>:
                                            <?php


                                                $phoenix_support = ( empty( $datum3->supports_phoenix ) ) ? '<span class="text-danger"><s>CE Phoenix</s></span>' : '<span class="text-success">CE Phoenix</span>';

                                                $osc_support = ( empty( $datum3->supports_osc ) ) ? '<span class="text-danger"><s>OSCommerce</s></span>' : '<span class="text-success">OSCommerce</span>';

                                                if (!empty($datum3->supports_osc)) {
                                                    if ( ! empty( $datum3->requires_osc ) ) {
                                                        $osc_support .= ' >=' . $datum3->requires_osc;
                                                        if ( ! zipCheckIfPhoenix() && empty( $osc_versionstatus[0] ) ) {
                                                            $osc_support = '<span class="text-danger"><s>' . $osc_support . '</s></span>';
                                                        }
                                                    }
                                                }
                                                if (!empty($datum3->supports_phoenix)) {
                                                    if ( ! empty( $datum3->requires_phoenix ) ) {
                                                        $phoenix_support .= ' >=' . $datum3->requires_phoenix;
                                                        if ( zipCheckIfPhoenix() && empty( $phoenix_versionstatus[0] ) ) {
                                                            $phoenix_support = '<span class="text-danger"><s>' . $phoenix_support . '</s></span>';
                                                        }
                                                    }
                                                }

                                                echo '<br/>(' . $phoenix_support . ') ';
                                                echo '(' . $osc_support . ') ';
                                            ?>
                                        </small>
                                    </div>
                                    <?php
                                        if ($datum3->type == 'app'){
                                            $typecolor = 'bg-warning text-dark';
                                        } else if ($datum3->type == 'hook'){
                                            $typecolor = 'bg-primary text-light';

                                        } else if ($datum3->type == 'module'){
                                            $typecolor = 'bg-info text-light';

                                        }

                                    ?>
                                    <div class="<?php echo $typecolor ;?>" style="border-radius: 0.5rem 0 0 0;position: absolute; bottom: 0px; right: 0px; padding: 3px 8px; ">
                                        <small><?php echo $datum3->type; ?></small>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php

                    }
                }
                echo '</div>';
            }
        }
        echo '</div>';

    } else if ( ! empty( $zipupdatecreator ) ) {
        echo '<p>' . TEXT_THIS_FILE_UPDATE_CREATOR_DESCRIPTION . '</p>';
        ?>
        <script>
            function zip_add_file() {
                var fileis = $(".select2-hidden-accessible option:selected").val();
                $("#update_install_files").append(fileis + "\n");
            }

            function zip_add_action(actionarea) {
                var getblank = $("#update_" + actionarea + "_action_blank_row").html();
                $("#update_" + actionarea + "_action_area").append('<tr>' + getblank + '</tr>');
                zip_triggers_actions();
            }

            function zip_triggers_actions() {
                $(".zip_update_action_type")
                    .change(function () {
                        var typevalue = $(this).val();
                        if (typevalue == 'ajax') {
                            $(this).parent().parent().children().last().html("<?php echo TEXT_THIS_FILE_UPDATE_CREATOR_AJAX_TIP; ?>");
                        } else if (typevalue == 'sql') {
                            $(this).parent().parent().children().last().html("<?php echo TEXT_THIS_FILE_UPDATE_CREATOR_SQL_TIP; ?>");
                        } else if (typevalue == 'files_delete') {
                            $(this).parent().parent().children().last().html("<?php echo TEXT_THIS_FILE_UPDATE_CREATOR_FILE_DELETE_TIP; ?>");
                        }
                    });
                $(".zip_update_delete_action")
                    .click(function () {
                        var typevalue = $(this).val();
                        $(this).parent().parent().remove();
                    });
            }

            $(function () {
                zip_triggers_actions();
            });
        </script>

        <div class="table-responsive">
            <div id="zipajaxupdate"></div>
            <?php
                if ( $updatebuildstep == 2 ) {

                    $update_original_name = zipVarCheck( "update_original_name", '' );
                    $update_name          = zipVarCheck( "update_name", '' );
                    $update_name          = preg_replace( '/[^a-zA-Z0-9-_]/', '', $update_name );

                    if ( ! empty( $update_name ) ) {
                        $update_tasks = zipVarCheck( "update_tasks", '' );

                        $update_description      = zipVarCheck( "update_description", '' );
                        $update_required_version = zipVarCheck( "update_required_version", '' );
                        $update_max_version      = zipVarCheck( "update_max_version", '' );

                        $osc_required_version = zipVarCheck( "osc_required_version", '' );
                        $osc_max_version      = zipVarCheck( "osc_max_version", '' );
                        $supports_osc         = zipVarCheck( "supports_osc", '' );
                        $supports_phoenix     = zipVarCheck( "supports_phoenix", '' );

                        $update_version                     = zipVarCheck( "update_version", '' );
                        $update_date                        = zipVarCheck( "update_date", '' );
                        $update_author                      = zipVarCheck( "update_author", '' );
                        $update_all_php                     = zipVarCheck( "update_all_php", '' );
                        $update_contact                     = zipVarCheck( "update_contact", '' );
                        $update_license                     = zipVarCheck( "update_license", '' );
                        $update_comments                    = zipVarCheck( "update_comments", '' );
                        $update_comments                    = preg_replace( "/\r\n|\n\r|\r|\n/", "\n", $update_comments );
                        $update_license                     = preg_replace( "/\r\n|\n\r|\r|\n/", "\n", $update_license );
                        $update_preinstall_action_type      = zipVarCheck( "update_preinstall_action_type", '' );
                        $update_preinstall_action_action    = zipVarCheck( "update_preinstall_action_action", '' );
                        $update_preinstall_action_optional  = zipVarCheck( "update_preinstall_action_optional", '' );
                        $update_preinstall_action_items     = zipVarCheck( "update_preinstall_action_items", '' );
                        $update_install_files               = zipVarCheck( "update_install_files", '' );
                        $update_postinstall_action_type     = zipVarCheck( "update_postinstall_action_type", '' );
                        $update_postinstall_action_action   = zipVarCheck( "update_postinstall_action_action", '' );
                        $update_postinstall_action_optional = zipVarCheck( "update_postinstall_action_optional", '' );
                        $update_postinstall_action_items    = zipVarCheck( "update_postinstall_action_items", '' );
                        $update_uninstall_action_type       = zipVarCheck( "update_uninstall_action_type", '' );
                        $update_uninstall_action_action     = zipVarCheck( "update_uninstall_action_action", '' );
                        $update_uninstall_action_optional   = zipVarCheck( "update_uninstall_action_optional", '' );
                        $update_uninstall_action_items      = zipVarCheck( "update_uninstall_action_items", '' );
                        $update_pre_install_actions         = '$update_pre_install_actions = [' . PHP_EOL;
                        for ( $i = 0; $i < count( $update_preinstall_action_type ); $i ++ ) {
                            if ( ! empty( $update_preinstall_action_items[ $i ] ) ) {
                                $update_pre_install_actions           .= "\t[" . PHP_EOL;
                                $update_pre_install_actions           .= "\t\t'type'\t\t=> '{$update_preinstall_action_type[$i]}'," . PHP_EOL;
                                $update_pre_install_actions           .= "\t\t'action'\t=> '{$update_preinstall_action_action[$i]}'," . PHP_EOL;
                                $update_pre_install_actions           .= "\t\t'optional'\t=> {$update_preinstall_action_optional[$i]}," . PHP_EOL;
                                $update_pre_install_actions           .= "\t\t'items'\t\t=> [" . PHP_EOL;
                                $update_preinstall_action_items[ $i ] = preg_replace( "/\r\n|\n\r|\r|\n/", "\n", $update_preinstall_action_items[ $i ] );
                                $items                                = explode( "\n", $update_preinstall_action_items[ $i ] );
                                foreach ( $items as $item ) {
                                    $update_pre_install_actions .= "\t\t\t'{$item}'," . PHP_EOL;
                                }
                                $update_pre_install_actions .= "\t\t]," . PHP_EOL;
                                $update_pre_install_actions .= "\t]," . PHP_EOL;
                            }
                        }
                        $update_pre_install_actions  .= "];";
                        $update_post_install_actions = '$update_post_install_actions = [' . PHP_EOL;
                        for ( $i = 0; $i < count( $update_postinstall_action_type ); $i ++ ) {
                            if ( ! empty( $update_postinstall_action_items[ $i ] ) ) {
                                $update_post_install_actions           .= "\t[" . PHP_EOL;
                                $update_post_install_actions           .= "\t\t'type'\t\t=> '{$update_postinstall_action_type[$i]}'," . PHP_EOL;
                                $update_post_install_actions           .= "\t\t'action'\t=> '{$update_postinstall_action_action[$i]}'," . PHP_EOL;
                                $update_post_install_actions           .= "\t\t'optional'\t=> {$update_postinstall_action_optional[$i]}," . PHP_EOL;
                                $update_post_install_actions           .= "\t\t'items'\t\t=> [" . PHP_EOL;
                                $update_postinstall_action_items[ $i ] = preg_replace( "/\r\n|\n\r|\r|\n/", "\n", $update_postinstall_action_items[ $i ] );
                                $items                                 = explode( "\n", $update_postinstall_action_items[ $i ] );
                                foreach ( $items as $item ) {
                                    $update_post_install_actions .= "\t\t\t'{$item}'," . PHP_EOL;
                                }
                                $update_post_install_actions .= "\t\t]," . PHP_EOL;
                                $update_post_install_actions .= "\t]," . PHP_EOL;
                            }
                        }
                        $update_post_install_actions .= "];";

                        $update_uninstall_actions = '$update_uninstall_actions = [' . PHP_EOL;
                        for ( $i = 0; $i < count( $update_uninstall_action_type ); $i ++ ) {
                            if ( ! empty( $update_uninstall_action_items[ $i ] ) ) {
                                $update_uninstall_actions            .= "\t[" . PHP_EOL;
                                $update_uninstall_actions            .= "\t\t'type'\t\t=> '{$update_uninstall_action_type[$i]}'," . PHP_EOL;
                                $update_uninstall_actions            .= "\t\t'action'\t=> '{$update_uninstall_action_action[$i]}'," . PHP_EOL;
                                $update_uninstall_actions            .= "\t\t'optional'\t=> {$update_uninstall_action_optional[$i]}," . PHP_EOL;
                                $update_uninstall_actions            .= "\t\t'items'\t\t=> [" . PHP_EOL;
                                $update_uninstall_action_items[ $i ] = preg_replace( "/\r\n|\n\r|\r|\n/", "\n", $update_uninstall_action_items[ $i ] );
                                $items                               = explode( "\n", $update_uninstall_action_items[ $i ] );
                                foreach ( $items as $item ) {
                                    $update_uninstall_actions .= "\t\t\t'{$item}'," . PHP_EOL;
                                }
                                $update_uninstall_actions .= "\t\t]," . PHP_EOL;
                                $update_uninstall_actions .= "\t]," . PHP_EOL;
                            }
                        }
                        $update_uninstall_actions .= "];";

                        $update_config = '$update_config = [' . PHP_EOL;
                        $update_config .= "\t'description'\t\t=> '{$update_description}'," . PHP_EOL;
                        $update_config .= "\t'required_version'\t=> '{$update_required_version}'," . PHP_EOL;
                        $update_config .= "\t'max_version'\t\t=> '{$update_max_version}'," . PHP_EOL;

                        $update_config .= "\t'osc_required_version'\t=> '{$osc_required_version}'," . PHP_EOL;
                        $update_config .= "\t'osc_max_version'\t=> '{$osc_max_version}'," . PHP_EOL;
                        $update_config .= "\t'supports_osc'\t\t=> $supports_osc," . PHP_EOL;
                        $update_config .= "\t'supports_phoenix'\t\t=> $supports_phoenix," . PHP_EOL;

                        $update_config .= "\t'update_version'\t=> '{$update_version}'," . PHP_EOL;
                        $update_config .= "\t'update_date'\t\t=> '{$update_date}'," . PHP_EOL;
                        $update_config .= "\t'update_author'\t\t=> '{$update_author}'," . PHP_EOL;
                        $update_config .= "\t'update_all_php'\t=> {$update_all_php}," . PHP_EOL;
                        $update_config .= "\t'update_contact'\t=> '{$update_contact}'," . PHP_EOL;
                        $update_config .= "\t'update_license'\t=> '{$update_license}'," . PHP_EOL;
                        $update_config .= "\t'update_comments'\t=> '{$update_comments}'," . PHP_EOL;
                        $update_config .= "\t'tasks'\t\t\t=> '{$update_tasks}'," . PHP_EOL;
                        $update_config .= '];';

                        //make update.php
                        $update_comments   = preg_replace( "/\n/", PHP_EOL . "* ", $update_comments );
                        $update_license    = preg_replace( "/\n/", PHP_EOL . "* ", $update_license );
                        $phpheadercomments = '' . PHP_EOL;
                        $phpheadercomments .= '/*' . PHP_EOL;
                        $phpheadercomments .= '* $Id: __ZIP__FILE__HERE__' . PHP_EOL;
                        $phpheadercomments .= '* $Loc: __ZIP__FOLDER__HERE__' . PHP_EOL;
                        $phpheadercomments .= '*' . PHP_EOL;
                        $phpheadercomments .= '* Name: ' . $update_name . PHP_EOL;
                        $phpheadercomments .= '* Version: ' . $update_version . PHP_EOL;
                        $phpheadercomments .= '* Release Date: ' . $update_date . PHP_EOL;
                        $phpheadercomments .= '* Author: ' . $update_author . PHP_EOL;
                        $phpheadercomments .= "* \t " . $update_contact . PHP_EOL;
                        $phpheadercomments .= '*' . PHP_EOL;
                        $phpheadercomments .= '* License: ' . $update_license . PHP_EOL;
                        $phpheadercomments .= '*' . PHP_EOL;
                        $phpheadercomments .= '* Comments: ' . $update_comments . PHP_EOL;
                        $phpheadercomments .= '*' . PHP_EOL;
                        $phpheadercomments .= '* (Packaged with zipurUpdater v' . $zipUpdaterVersion . ')' . PHP_EOL;
                        $phpheadercomments .= '*/' . PHP_EOL . PHP_EOL;

                        //$update_version
                        $foldertext  = $update_name . '_' . str_replace( '.', '_', $update_version );
                        $tofolder    = $updatesBaseDirectory . $foldertext;
                        $oktoproceed = 1;

                        //delete previous folder to make room for changes
                        zipDeleteDirectory( $tofolder );

                        if ( ! file_exists( $tofolder ) ) {
                            if ( ! mkdir( $tofolder, 0755 ) ) {
                                echo '<span class="text-danger">' . TEXT_UPDATES_DIRECTORY_CREATE_ERROR . '</span>';
                                $oktoproceed = 0;
                            }
                        }

                        if ( ! empty( $update_install_files ) ) {
                            $items = explode( "\n", $update_install_files );
                            foreach ( $items as $item ) {
                                $item = preg_replace( "/\r/", "", "{$item}" );

                                $itemto         = preg_replace( '/^\/' . $customadminpath . '\//', '/admin/', $item, 1 );
                                $itemfrom       = preg_replace( '/^\/admin\//', '/' . $customadminpath . '/', $item, 1 );
                                $fromfile       = DIR_FS_CATALOG . $itemfrom;
                                $tofile         = $tofolder . $itemto;
                                $newdirectories = explode( '/', $itemto );
                                $dircount       = 1;
                                $lastdir        = '';
                                foreach ( $newdirectories as $newdirectory ) {
                                    if ( $dircount > 1 && $dircount < count( $newdirectories ) ) {
                                        $lastdir .= '/' . $newdirectory;
                                        if ( ! file_exists( $tofolder . $lastdir ) ) {
                                            if ( ! mkdir( $tofolder . $lastdir, 0755 ) ) {
                                                echo '<span class="text-danger">' . TEXT_UPDATES_DIRECTORY_CREATE_ERROR . ' - ' . $tofolder . $lastdir . '</span>';
                                                $oktoproceed = 0;
                                            }
                                        }
                                    }
                                    $dircount ++;
                                }
                                $fromfile = str_replace( '//', '/', $fromfile );
                                if ( empty( $item ) ) {
                                    $oktoproceed = 0;
                                }
                                if ( ! file_exists( $tofolder ) ) {
                                    if ( ! mkdir( $tofolder, 0755 ) ) {
                                        echo '<span class="text-danger">' . TEXT_UPDATES_DIRECTORY_CREATE_ERROR . '</span>';
                                        $oktoproceed = 0;
                                    }
                                }
                                if ( ! empty( $oktoproceed ) ) {
                                    if ( ! copy( $fromfile, $tofile ) ) {
                                        $note = '<span class="text-danger">' . TEXT_UPDATES_FILE_COPY_FAIL . ':<br/>' . TEXT_UPDATES_FILE_FROM . ': ' . $fromfile . '<br/>' . TEXT_UPDATES_FILE_TO . ': ' . $tofile . '</span>';
                                    } else {
                                        //                                        $note = '<span class="text-success">' . TEXT_UPDATES_FILE_COPIED . ': ' . $tofile . '</span>';
                                        $note = '';
                                        if ( ! empty( $update_all_php ) ) {
                                            //replace header comments of file
                                            if ( strpos( $tofile, '.php' ) !== false ) {

                                                $getfile       = file_get_contents( $tofile );
                                                $checkstartloc = strpos( $getfile, '/*' );
                                                $checkendloc   = strpos( $getfile, '*/' );
                                                if ( $checkstartloc < 20 ) {
                                                    $oldcomment = substr( $getfile, $checkstartloc, $checkendloc - $checkstartloc + 2 );

                                                    $commenttoplace = str_replace( '__ZIP__FILE__HERE__', basename( $itemto ), $phpheadercomments );
                                                    $pathx          = str_replace( basename( basename( $itemto ) ), '', $itemto );
                                                    $commenttoplace = str_replace( '__ZIP__FOLDER__HERE__', $pathx, $commenttoplace );

                                                    $getfile = str_replace( $oldcomment, $commenttoplace, $getfile );
                                                    $changefile = fopen( $tofile, "w" ) or die( TEXT_UPDATES_FILE_UPDATE_CREATE_FAILED );
                                                    fwrite( $changefile, $getfile );
                                                    fclose( $changefile );
                                                }
                                            }
                                        }

                                    }
                                    echo $note . '<br/>';
                                }

                            }
                        }

                        $commenttoplace = str_replace( '__ZIP__FILE__HERE__', 'update.php', $phpheadercomments );
                        $commenttoplace = str_replace( '__ZIP__FOLDER__HERE__', 'admin/updates/' . $update_name, $commenttoplace );

                        $updatecode = '';
                        $updatecode .= '<?php' . PHP_EOL . PHP_EOL;
                        $updatecode .= $commenttoplace;
                        $updatecode .= $update_config;
                        $updatecode .= PHP_EOL . PHP_EOL . $update_pre_install_actions . PHP_EOL;
                        $updatecode .= PHP_EOL . PHP_EOL . $update_post_install_actions . PHP_EOL;
                        $updatecode .= PHP_EOL . PHP_EOL . $update_uninstall_actions . PHP_EOL;
                        $updatecode .= PHP_EOL . PHP_EOL . '?>';
                        $updatefile = fopen( $tofolder . '/update.php', "w" ) or die( TEXT_UPDATES_FILE_UPDATE_CREATE_FAILED . ' ' . $tofolder . '/update.php' );
                        fwrite( $updatefile, $updatecode );
                        fclose( $updatefile );

                    }
                    $updatebuildstep = 0;//show list of updates

                }

                if ( $updatebuildstep == 0 ) {

                echo '<a class="btn btn-sm btn-outline-secondary m-2" href="zipur_toolbox.php?zipedit=newpackage&zipupdatecreator=1&updatebuildstep=1&updatefolder=newpackage">' . TEXT_THIS_FILE_UPDATE_CREATOR_NEW . '</a>';

                //create base updates directory
                if ( ! file_exists( $updatesBaseDirectory ) ) {
                    if ( ! mkdir( $updatesBaseDirectory, 0700 ) ) {
                        echo '<span class="text-danger">' . TEXT_UPDATES_DIRECTORY_CREATE_ERROR . '</span>';
                    }
                }

                //list folders
                exec( 'ls ' . $updatesBaseDirectory, $files );
                ?>

                <table class="table table-striped table-hover">
                    <thead class="thead-dark">
                    <tr>
                        <th class="col-md-2"><?php echo TABLE_HEADING_FOLDER; ?></th>
                        <th class="col-md-5"><?php echo TABLE_HEADING_DESCRIPTION; ?></th>
                        <th class="col-md-1"><?php echo TABLE_HEADING_REQUIRED_VERSION; ?></th>
                        <th class="col-md-1"><?php echo TABLE_HEADING_MAX_VERSION; ?></th>
                        <th class="text-right col-md-3"><?php echo TABLE_HEADING_TASKS; ?></th>
                    </tr>
                    </thead>
                    <tbody>
                    <?php
                        if ( empty( $files ) ) {
                            echo '<br/><br/>' . TEXT_UPDATES_EMPTY . '<br/><br/>';
                        }
                        foreach (
                            $files

                            as $folder
                        ) {
                            $thisfolder = $updatesBaseDirectory . '' . $folder;

                            if ( is_dir( $thisfolder ) ) {

                                $installhash = hash( 'sha256', $folder );

                                //check for update.php in each folder
                                if ( file_exists( $thisfolder . '/update.php' ) ) {

                                    require( $thisfolder . '/update.php' );

                                    $maxver = ( zipCheckIfPhoenix() ) ? $update_config['max_version'] : $update_config['osc_max_version'];
                                    $reqver = ( zipCheckIfPhoenix() ) ? $update_config['required_version'] : $update_config['osc_required_version'];

                                    $supported = ( zipCheckIfPhoenix() ) ? $update_config['supports_phoenix'] : $update_config['supports_osc'];

                                    /** @var array $update_config */
                                    $versionstatus = zipCheckUpdateVersion( $reqver, $maxver );
                                    $versioncolor1 = ( $versionstatus[0] ) ? 'text-success' : 'text-danger';
                                    $versioncolor2 = ( $versionstatus[1] ) ? 'text-success' : 'text-danger';
                                    if ( empty( $versionstatus[0] ) || empty( $versionstatus[1] ) || empty( $supported ) ) {
                                        $update_config['tasks'] = '<span class="text-danger">' . TEXT_UPDATES_MISSING_REQUIRED_VERSION . '</span>';
                                    }
                                    $zipfile = '<a href="zipur_toolbox.php?zipzip=' . $installhash . '&zipupdatecreator=1&updatebuildstep=1&updatefolder=' . $folder . '"><i class="fas fa-file-archive"></i></a> ';

                                    $update_config['tasks'] = '<a class="btn btn-sm btn-outline-secondary mt-2 ml-2" href="zipur_toolbox.php?zipedit=' . $installhash . '&zipupdatecreator=1&updatebuildstep=1&updatefolder=' . $folder . '">' . TEXT_THIS_FILE_UPDATE_CREATOR_EDIT . '</a>';
                                    if ( empty( $update_config['update_version'] ) ) {
                                        $update_config['update_version'] = '';
                                    }

                                    $foldertext = str_replace( '_' . str_replace( '.', '_', $update_config['update_version'] ), '', $folder );

                                    zipurRow( $zipfile . $foldertext . '<br/>' .
                                              $update_config['update_version'], $update_config['description'], '<span class="' . $versioncolor1 . '">' . $reqver . '</span>', '<span class="' . $versioncolor2 . '">' . $maxver . '</span>', $update_config['tasks'] );
                                } else if ( strpos( $thisfolder, '_zip.zip' ) !== false ) {
                                    //clean up zip files generated by downloader
                                    unlink( $thisfolder );

                                }
                            }
                        }

                    ?>
                    </tbody>
                </table>
                <?php
            } else if ( $updatebuildstep == 1 ) {

                $thisfolder  = $updatesBaseDirectory . '' . $updatefolder;
                $installhash = hash( 'sha256', $updatefolder );

                //check for update.php in each folder
                if ( file_exists( $thisfolder . '/update.php' ) && hash( 'sha256', $updatefolder ) == $zipedit || $updatefolder == 'newpackage' ) {

                    if ( $updatefolder == 'newpackage' ) {
                        $updatefolder = '';

                        $min_default = ( zipCheckIfPhoenix() ) ? '1.0.0.0' : '2.3.0.0';
                        $max_default = ( zipCheckIfPhoenix() ) ? '1.9.9.9' : '2.9.9.9';

                        $update_config = [
                            'description'          => '',
                            'required_version'     => $min_default,
                            'max_version'          => $max_default,
                            'update_version'       => '',
                            'osc_required_version' => '',
                            'osc_max_version'      => '',
                            'supports_osc'         => false,
                            'supports_phoenix'     => true,
                            'update_date'          => '',
                            'update_all_php'       => false,
                            'update_author'        => TEXT_THIS_FILE_UPDATE_CREATOR_AUTHOR,
                            'update_contact'       => TEXT_THIS_FILE_UPDATE_CREATOR_CONTACT,
                            'update_license'       => TEXT_THIS_FILE_UPDATE_CREATOR_LICENSE,
                            'update_comments'      => TEXT_THIS_FILE_UPDATE_CREATOR_COMMENTS,
                            'tasks'                => 'install|remove',
                        ];

                    } else {
                        require( $thisfolder . '/update.php' );
                    }

                    $updatefoldershow = str_replace( '_' . str_replace( '.', '_', $update_config['update_version'] ), '', $updatefolder );

                    ?>
                    <h4 class="text-light bg-dark p-2"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_SETTINGS_TITLE; ?></h4>
                    <form action="zipur_toolbox.php" method="post">
                        <table class="table" style="font-size: 0.8rem;">
                            <tbody>
                            <tr>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_NAME_TEXT; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_name"
                                                            value="<?php echo $updatefoldershow; ?>"
                                                            size="50"/><br/>(a-z,A-Z,0-9,-,_)
                                </td>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_TASKS; ?>:</td>
                                <td class="col-md-4">
                                    <select name="update_tasks">
                                        <option value="install|remove" <?php echo ( strpos( $update_config['tasks'], 'remove' ) !== false ) ? 'SELECTED' : ''; ?>>
                                            <?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_INSTALL_TEXT; ?>
                                            & <?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_REMOVE_TEXT; ?>
                                        </option>
                                        <option value="install" <?php echo ( ! strpos( $update_config['tasks'], 'remove' ) !== false ) ? 'SELECTED' : ''; ?>>
                                            <?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_INSTALL_TEXT; ?>
                                        </option>
                                    </select>
                                </td>
                            </tr>
                            <tr>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_DESCRIPTION_TEXT; ?>
                                    :
                                </td>
                                <td class="col-md-4"><textarea rows="3" cols="50"
                                                               name="update_description"><?php echo $update_config['description']; ?></textarea>
                                </td>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_VERSION; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_version"
                                                            value="<?php echo $update_config['update_version']; ?>"
                                                            size="10"/></td>
                            </tr>

                            <tr>
                                <td rowspan="2" class="col-md-2 text-right">CE
                                    Phoenix <?php echo TEXT_UPDATES_FILE_UPDATE_CREATE_UPDATE_COMPATIBLE; ?>
                                    :
                                </td>
                                <td rowspan="2" class="col-md-4">
                                    <select name="supports_phoenix">
                                        <option value="true" <?php if ( $update_config['supports_phoenix'] == true ) {
                                            echo 'SELECTED';
                                        } ?>><?php echo TEXT_THIS_FILE_REPORT_YES; ?></option>
                                        <option value="false" <?php if ( $update_config['supports_phoenix'] == false ) {
                                            echo 'SELECTED';
                                        } ?>><?php echo TEXT_THIS_FILE_REPORT_NO; ?></option>
                                    </select>
                                </td>
                                <td class="col-md-2 text-right"><?php echo 'CE Phoenix ' . TABLE_HEADING_REQUIRED_VERSION; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_required_version"
                                                            value="<?php echo $update_config['required_version']; ?>"
                                                            size="10"/></td>
                            </tr>

                            <tr>
                                <td class="col-md-2 text-right"><?php echo 'CE Phoenix ' . TABLE_HEADING_MAX_VERSION; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_max_version"
                                                            value="<?php echo $update_config['max_version']; ?>"
                                                            size="10"/></td>
                            </tr>

                            <tr>
                                <td rowspan="2" class="col-md-2 text-right">
                                    OSCommerce <?php echo TEXT_UPDATES_FILE_UPDATE_CREATE_UPDATE_COMPATIBLE; ?>
                                    :
                                </td>
                                <td rowspan="2" class="col-md-4">
                                    <select name="supports_osc">
                                        <option value="true" <?php if ( $update_config['supports_osc'] == true ) {
                                            echo 'SELECTED';
                                        } ?>><?php echo TEXT_THIS_FILE_REPORT_YES; ?></option>
                                        <option value="false" <?php if ( $update_config['supports_osc'] == false ) {
                                            echo 'SELECTED';
                                        } ?>><?php echo TEXT_THIS_FILE_REPORT_NO; ?></option>
                                    </select>
                                </td>
                                <td class="col-md-2 text-right"><?php echo 'OSCommerce ' . TABLE_HEADING_REQUIRED_VERSION; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="osc_required_version"
                                                            value="<?php echo $update_config['osc_required_version']; ?>"
                                                            size="10"/></td>
                            </tr>

                            <tr>
                                <td class="col-md-2 text-right"><?php echo 'OSCommerce ' . TABLE_HEADING_MAX_VERSION; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="osc_max_version"
                                                            value="<?php echo $update_config['osc_max_version']; ?>"
                                                            size="10"/></td>
                            </tr>


                            <tr>

                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_DATE; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_date" id="update_date"
                                                            value="<?php echo $update_config['update_date']; ?>"
                                                            size="10"/></td>
                            </tr>
                            <tr>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_AUTHOR; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_author"
                                                            value="<?php echo $update_config['update_author']; ?>"
                                                            size="30"/></td>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_CONTACT; ?>
                                    :
                                </td>
                                <td class="col-md-4"><input type="text" name="update_contact"
                                                            value="<?php echo $update_config['update_contact']; ?>"
                                                            size="30"/></td>
                            </tr>
                            <tr>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_LICENSE; ?>
                                    :
                                </td>
                                <td class="col-md-4"><textarea name="update_license" rows="3"
                                                               cols="50"><?php echo $update_config['update_license']; ?></textarea>
                                </td>
                                <td class="col-md-2 text-right"><?php echo TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_COMMENTS; ?>
                                    :
                                </td>
                                <td class="col-md-4"><textarea name="update_comments" rows="3"
                                                               cols="50"><?php echo $update_config['update_comments']; ?></textarea>
                                </td>
                            </tr>
                            <tr>
                                <td class="col-md-2 text-right"><?php echo TEXT_UPDATES_FILE_UPDATE_CREATE_UPDATE_PHP; ?>
                                    :
                                </td>
                                <td class="col-md-4">
                                    <select name="update_all_php">
                                        <option value="true"><?php echo TEXT_THIS_FILE_REPORT_YES; ?></option>
                                        <option value="false"><?php echo TEXT_THIS_FILE_REPORT_NO; ?></option>
                                    </select>
                                </td>
                                <td class="col-md-2 text-right"></td>
                                <td class="col-md-4"></td>
                            </tr>
                            </tbody>
                        </table>

                        <script>
                            $(function () {
                                $('#update_date').datepicker({
                                    changeMonth: true,
                                    changeYear: true,
                                    showButtonPanel: true
                                });
                            });
                        </script>
                        <?php
                            zipUpdaterActionBuilder( $update_pre_install_actions, TEXT_THIS_FILE_UPDATE_CREATOR_PRE_INSTALL_TITLE, 'preinstall' );
                            zipUpdaterFileBuilder();
                            zipUpdaterActionBuilder( $update_post_install_actions, TEXT_THIS_FILE_UPDATE_CREATOR_POST_INSTALL_TITLE, 'postinstall' );
                            zipUpdaterActionBuilder( $update_uninstall_actions, TEXT_THIS_FILE_UPDATE_CREATOR_UN_INSTALL_TITLE, 'uninstall' );
                            echo '<button class="btn btn-success m-2 float-right">' . TEXT_THIS_FILE_UPDATE_CREATOR_SAVE . '</button>';
                        ?>
                        <input type="hidden" name="update_original_name" value="<?php echo $updatefolder; ?>"/>
                        <input type="hidden" name="zipedit" value="<?php echo $installhash; ?>"/>
                        <input type="hidden" name="zipupdatecreator" value="1"/>
                        <input type="hidden" name="updatebuildstep" value="2"/>
                    </form>
                    <?php
                }
            ?>
        </div>
    <hr>
        <p><?php echo TEXT_UPDATES_DIRECTORY . ' ' . $updatesBaseDirectory; ?></p>
        <?php
    }

    } else if ( ! empty( $zipreport ) ) {

        echo '<p>' . TEXT_THIS_FILE_REPORT_DESCRIPTION . '</p>';

        if ( ! zipCheckIfPhoenix() ) {

            $versionpath      = 'oscommerce-';
            $newurl           = '';
            $extracatalogpath = '/catalog';

        } else {

            $newurl           = 'https://codeload.github.com/gburton/CE-Phoenix/zip/' . trim( $version );
            $versionpath      = 'CE-Phoenix-';
            $extracatalogpath = '';

        }

        if ( ! file_exists( DIR_FS_ADMIN . 'clean_core/' . $versionpath . trim( $version ) ) ) {
            if ( empty( $newurl ) ) {

                echo 'You need to download a full copy of OS Commerce ' . trim( $version ) . ' from <a href="https://www.oscommerce.com/Products" target="_blank">www.oscommerce.com</a> and unzip the file to <br/>' . DIR_FS_ADMIN . 'clean_core/oscommerce-' . trim( $version ) . '/';

            } else {
                if ( ! empty( $installstep ) ) {
                    if ( ! file_exists( DIR_FS_ADMIN . 'clean_core' ) ) {
                        if ( ! mkdir( DIR_FS_ADMIN . 'clean_core', 0700 ) ) {
                            echo '<span class="text-danger">' . TEXT_UPDATES_DIRECTORY_CREATE_ERROR . '</span>';
                        }
                    }

                    $newpath = DIR_FS_ADMIN . 'clean_core/' . trim( $version ) . '.zip';
                    $fp      = fopen( $newpath, 'w+' );
                    $ch      = curl_init();
                    curl_setopt( $ch, CURLOPT_URL, $newurl );
                    curl_setopt( $ch, CURLOPT_RETURNTRANSFER, false );
                    curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
                    curl_setopt( $ch, CURLOPT_CONNECTTIMEOUT, 10 );
                    curl_setopt( $ch, CURLOPT_FILE, $fp );
                    curl_exec( $ch );
                    curl_close( $ch );
                    fclose( $fp );

                    if ( ! file_exists( $newpath ) ) {
                        echo '<span class="text-danger">' . TEXT_THIS_FILE_REPORT_DOWNLOAD_ERROR . ' (' . $versionpath . trim( $version ) . '.zip)</span>';
                    } else {
                        echo '<span class="text-success">' . TEXT_THIS_FILE_REPORT_DOWNLOAD_SUCCESS . ' (' . $versionpath . trim( $version ) . '.zip)</span>';
                        $zip = new ZipArchive;
                        $res = $zip->open( $newpath );
                        if ( $res === true ) {
                            $zip->extractTo( DIR_FS_ADMIN . 'clean_core/' );
                            $zip->close();
                            echo '<br/><span class="text-success">' . TEXT_THIS_FILE_REPORT_UNZIP_SUCCESS . '</span>';
                            unlink( $newpath );//deletes downloaded zip
                        } else {
                            echo '<br/><span class="text-danger">' . TEXT_THIS_FILE_REPORT_UNZIP_FAILED . ' (' . $newpath . ')</span>';
                        }

                    }

                } else {
                    echo TEXT_THIS_FILE_REPORT_VERSION_FOLDER_ERROR;
                    ?>
                    <nav class="navbar navbar-light bg-light">
                        <a class="btn btn-sm btn-outline-secondary"
                           href="zipur_toolbox.php"><?php echo TEXT_THIS_FILE_REPORT_NO; ?></a>
                        <a class="btn btn-sm btn-outline-secondary"
                           href="zipur_toolbox.php?zipreport=1&versiondownload=1"><?php echo TEXT_THIS_FILE_REPORT_YES; ?></a>
                    </nav>
                    <?php
                }
            }
        } else {

            //setup array for existing install
            zipGetDirArray( DIR_FS_CATALOG, [
                'images',
                'updates',
                'old',
                'install',
                'clean_core',
                'README',
                'README.md',
            ], 0 );

            echo DIR_FS_ADMIN . 'clean_core/' . $versionpath . trim( $version ) . $extracatalogpath;
            //setup array for clean core (same version)
            zipGetDirArray( DIR_FS_ADMIN . 'clean_core/' . $versionpath . trim( $version ) . $extracatalogpath, [
                'images',
                'updates',
                'old',
                'clean_core',
                'README',
                'README.md',
            ], 1 );

            foreach ( $installedfiles as $installedfilekey => $installedfile ) {
                if ( empty( $cleancorefiles[ $installedfilekey ] ) ) {
                    $zip_added_files[] = $installedfilekey;
                } else if ( $cleancorefiles[ $installedfilekey ] != $installedfile ) {
                    $zip_altered_files[] = $installedfilekey;
                }
            }

            foreach ( $cleancorefiles as $cleancorefilekey => $cleancorefile ) {
                if ( empty( $installedfiles[ $cleancorefilekey ] ) ) {
                    $zip_missing_files[] = $cleancorefilekey;
                }
            }

            /** Generate report row
             *
             * @param     $class
             * @param     $title
             * @param     $filepath
             * @param int $padding1
             * @param int $padding2
             *
             * @return string
             */
            function zipReportRow( $class, $title, $filepath, $padding1 = 0, $padding2 = 0 ) {

                return <<<html
               <tr>
                    <td class="col-md-2 p-{$padding1} text-right {$class}">{$title}&nbsp;</td>
                    <td class="col-md-10 p-{$padding2}">&nbsp;{$filepath}</td>
                </tr>
               html;
            }

            ?>

            <ul class="nav nav-tabs" id="zipReportTab" role="tablist">
                <li class="nav-item">
                    <a class="nav-link active" id="added-tab" data-toggle="tab" href="#added" role="tab"
                       aria-controls="added"
                       aria-selected="true"><?php echo TEXT_THIS_FILE_REPORT_FILE_ADDED; ?></a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" id="altered-tab" data-toggle="tab" href="#altered" role="tab"
                       aria-controls="altered"
                       aria-selected="false"><?php echo TEXT_THIS_FILE_REPORT_FILE_ALTERED; ?></a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" id="removed-tab" data-toggle="tab" href="#removed" role="tab"
                       aria-controls="removed"
                       aria-selected="false"><?php echo TEXT_THIS_FILE_REPORT_FILE_REMOVED; ?></a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" id="versions-tab" data-toggle="tab" href="#versions" role="tab"
                       aria-controls="versions"
                       aria-selected="false"><?php echo TEXT_THIS_FILE_REPORT_FILE_VERSIONS; ?></a>
                </li>
            </ul>
            <div class="tab-content" id="zipReportTabContent">
                <div class="tab-pane fade show active" id="added" role="tabpanel" aria-labelledby="added-tab">
                    <table class="table">
                        <tbody>
                        <?php
                            foreach ( $zip_added_files as $zip_added_file ) {
                                echo zipReportRow( 'text-warning', TEXT_THIS_FILE_REPORT_FILE_ADDED, $zip_added_file );
                            }
                        ?>
                        </tbody>
                    </table>
                </div>
                <div class="tab-pane fade" id="altered" role="tabpanel" aria-labelledby="altered-tab">
                    <table class="table">
                        <tbody>

                        <?
                            foreach ( $zip_altered_files as $zip_altered_file ) {
                                echo zipReportRow( 'text-danger', TEXT_THIS_FILE_REPORT_FILE_ALTERED, $zip_altered_file );
                            }
                        ?>
                        </tbody>
                    </table>
                </div>
                <div class="tab-pane fade" id="removed" role="tabpanel" aria-labelledby="removed-tab">
                    <table class="table">
                        <tbody>
                        <?php
                            foreach ( $zip_missing_files as $zip_missing_file ) {
                                echo zipReportRow( 'text-danger', TEXT_THIS_FILE_REPORT_FILE_REMOVED, $zip_missing_file );
                            }
                        ?>
                        </tbody>
                    </table>
                </div>
                <div class="tab-pane fade" id="versions" role="tabpanel" aria-labelledby="versions-tab">
                    <table class="table">
                        <tbody>
                        <?php
                            exec( 'ls ' . DIR_FS_ADMIN . 'clean_core/', $cleancorefileitems );
                            if ( ! empty( $cleancorefileitems ) ) { ?>
                                <table class="table">
                                    <tbody>
                                    <?php
                                        foreach ( $cleancorefileitems as $cleancorefileitem ) {
                                            $deletehash = hash( 'sha256', DIR_FS_ADMIN . 'clean_core/' . $cleancorefileitem );
                                            echo zipReportRow( 'text-info', '<a class="btn btn-sm btn-outline-secondary mt-2 ml-2" href="zipur_toolbox.php?zipreport=1&deletecleancore=' . $deletehash . '">' . TEXT_UPDATES_ACTION_DELETE . '</a>', DIR_FS_ADMIN . 'clean_core/' . $cleancorefileitem, 0, 6 );
                                        }
                                    ?>
                                    </tbody>
                                </table>
                                <?php
                            }
                        ?>
                        </tbody>
                    </table>
                </div>
            </div>
            <?php
        }
    } else {
        ?>

        <script>
            function zip_module_update(page, set, module, action) {
                var url = page + '?zipupdating=1';
                url += (set != '') ? '&set=' + set : '';
                url += (module != '') ? '&module=' + module : '';
                url += (action != '') ? '&action=' + action : '';
                $.ajax({
                    type: 'GET',
                    url: url,
                    success: function (json) {
                        $("#zipajaxupdate").append('<span class="success"></span>');
                    },
                    error: function (json) {
                        $("#zipajaxupdate").append('<span class="text-danger"></span>');
                    }
                });
            }

            var zipurfilehash = '';

            function zipDeleteThisUpdate(hash) {
                zipurfilehash = hash;
                document.getElementById('id01').style.display = 'block';
            }

            function zipDeleteThisUpdateNow() {
                window.location.href = 'zipur_toolbox.php?zipdelete=' + zipurfilehash;
                zipurfilehash = '';
            }

            function zipUninstallThisUpdate(hash) {
                zipurfilehash = hash;
                document.getElementById('id01').style.display = 'block';
            }

            function zipUninstallThisUpdateNow() {
                window.location.href = 'zipur_toolbox.php?zipdelete=' + zipurfilehash;
                zipurfilehash = '';
            }
        </script>
        <style>
            * {
                box-sizing: border-box
            }

            /* Set a style for all buttons */
            .modal button {
                background-color: #4CAF50;
                color: white;
                padding: 14px 20px;
                margin: 8px 0;
                border: none;
                cursor: pointer;
                width: 100%;
                opacity: 0.9;
            }

            .modal button:hover {
                opacity: 1;
            }

            /* Float cancel and delete buttons and add an equal width */
            .modal .cancelbtn, .modal .deletebtn {
                float: left;
                width: 50%;
            }

            /* Add a color to the cancel button */
            .modal .cancelbtn {
                background-color: #ccc;
                color: black;
            }

            /* Add a color to the delete button */
            .modal .deletebtn {
                background-color: #f44336;
            }

            /* Add padding and center-align text to the container */
            .modal .container {
                padding: 16px;
                text-align: center;
            }

            /* The Modal (background) */
            .modal {
                display: none; /* Hidden by default */
                position: fixed; /* Stay in place */
                z-index: 1; /* Sit on top */
                left: 0;
                top: 0;
                width: 100%; /* Full width */
                height: 100%; /* Full height */
                overflow: auto; /* Enable scroll if needed */
                background-color: #474e5d;
                padding-top: 50px;
            }

            /* Modal Content/Box */
            .modal-content {
                background-color: #fefefe;
                margin: 5% auto 15% auto; /* 5% from the top, 15% from the bottom and centered */
                border: 1px solid #888;
                width: 80%; /* Could be more or less, depending on screen size */
            }

            /* Style the horizontal ruler */
            .modal hr {
                border: 1px solid #f1f1f1;
                margin-bottom: 25px;
            }

            /* The Modal Close Button (x) */
            .modal .close {
                position: absolute;
                right: 35px;
                top: 15px;
                font-size: 40px;
                font-weight: bold;
                color: #f1f1f1;
            }

            .modal .close:hover,
            .modal .close:focus {
                color: #f44336;
                cursor: pointer;
            }

            /* Clear floats */
            .modal .clearfix::after {
                content: "";
                clear: both;
                display: table;
            }

            /* Change styles for cancel button and delete button on extra small screens */
            @media screen and (max-width: 300px) {
                .modal .cancelbtn, .modal .deletebtn {
                    width: 100%;
                }
            }
        </style>
        <div class="table-responsive">
            <div id="zipajaxupdate"></div>
            <?php
                //create base updates directory
                if ( ! file_exists( $updatesBaseDirectory ) ) {
                    if ( ! mkdir( $updatesBaseDirectory, 0700 ) ) {
                        echo '<span class="text-danger">' . TEXT_UPDATES_DIRECTORY_CREATE_ERROR . '</span>';
                    }
                }
                //list folders
                exec( 'ls ' . $updatesBaseDirectory, $files );
            ?>
            <table class="table table-striped table-hover">
                <thead class="thead-dark">
                <tr>
                    <th class="col-md-2"><?php echo TABLE_HEADING_FOLDER; ?></th>
                    <th class="col-md-5"><?php echo TABLE_HEADING_DESCRIPTION; ?></th>
                    <th class="col-md-1"><?php echo TABLE_HEADING_REQUIRED_VERSION; ?></th>
                    <th class="col-md-1"><?php echo TABLE_HEADING_MAX_VERSION; ?></th>
                    <th class="text-right col-md-3"><?php echo TABLE_HEADING_TASKS; ?></th>
                </tr>
                </thead>
                <tbody>
                <?php
                    if ( empty( $files ) ) {
                        echo '<br/><br/>' . TEXT_UPDATES_EMPTY . '<br/><br/>';
                    }
                    foreach (
                        $files

                        as $folder
                    ) {
                        $thisfolder = $updatesBaseDirectory . '' . $folder;

                        if ( is_dir( $thisfolder ) ) {
                            ?>

                            <?php
                            $installhash = hash( 'sha256', $folder );

                            if ( $zipinstall == $installhash || empty( $zipinstall ) ) {
                                //check for update.php in each folder
                                if ( ! file_exists( $thisfolder . '/update.php' ) ) {
                                    $update_config = [
                                        'required_version'     => '1.0.0.0',
                                        'max_version'          => '1.0.0.0',
                                        'osc_required_version' => '1.0.0.0',
                                        'osc_max_version'      => '1.0.0.0',
                                        'description'          => TEXT_THIS_UPDATE_MISSING_FILE,
                                        'update_version'       => '',
                                        'update_date'          => '',
                                        'update_all_php'       => '',
                                        'update_author'        => '',
                                        'update_contact'       => '',
                                        'update_license'       => '',
                                        'update_comments'      => '',
                                        'tasks'                => '',
                                        'supports_osc'         => false,
                                        'supports_phoenix'     => true,
                                    ];

                                } else {
                                    require $thisfolder . '/update.php';
                                }

                                $maxver    = ( zipCheckIfPhoenix() ) ? $update_config['max_version'] : $update_config['osc_max_version'];
                                $reqver    = ( zipCheckIfPhoenix() ) ? $update_config['required_version'] : $update_config['osc_required_version'];
                                $supported = ( zipCheckIfPhoenix() ) ? $update_config['supports_phoenix'] : $update_config['supports_osc'];

                                $versionstatus = zipCheckUpdateVersion( $reqver, $maxver );
                                $versioncolor1 = ( $versionstatus[0] ) ? 'text-success' : 'text-danger';
                                $versioncolor2 = ( $versionstatus[1] ) ? 'text-success' : 'text-danger';
                                if ( empty( $versionstatus[0] ) || empty( $versionstatus[1] ) || empty( $supported ) ) {
                                    $update_config['tasks'] = '<span class="text-danger">' . TEXT_UPDATES_MISSING_REQUIRED_VERSION . '</span>';
                                }

                                //TEXT_UPDATES_ACTION_REINSTALL
                                $sameversion    = 0;
                                $needsupgrade   = 0;
                                $cleancorefiles = [];
                                zipGetDirArray( $thisfolder, [ 'update.php' ], 2 );
                                if ( ! empty( $cleancorefiles ) ) {
                                    $cleancorefiles[0] = preg_replace( '/' . $customadminpath . '\/updates\/' . $folder . '\/admin/', $customadminpath . '/updates/' . $folder . '/' . $customadminpath, $cleancorefiles[0], 1 );
                                    $cleancorefiles[0] = preg_replace( '/' . $customadminpath . '\/updates\/' . $folder . '\//', '', $cleancorefiles[0], 1 );

                                    if ( file_exists( $cleancorefiles[0] ) ) {

                                        $vertext       = '';
                                        $getcheckfile  = file_get_contents( $cleancorefiles[0] );
                                        $checkstartloc = strpos( $getcheckfile, 'Version' );
                                        $checkendloc   = strpos( $getcheckfile, "\n", $checkstartloc );
                                        if ( ( $checkendloc - $checkstartloc ) < 30 ) {
                                            $versiontext = substr( $getcheckfile, $checkstartloc, $checkendloc - $checkstartloc + 2 );
                                            $versiontext = preg_replace( '/[^0-9.]/', '', $versiontext );
                                            $verok       = zipCheckNeedsUpdateVersion( $versiontext, $update_config['update_version'] );
                                            if ( empty( $verok ) ) {
                                                $needsupgrade = 1;
                                            } else {
                                                $sameversion = 1;
                                            }
                                        }
                                    }

                                }

                                $installbuttontext = ( ! empty( $needsupgrade ) ) ? TEXT_UPDATES_ACTION_UPGRADE : TEXT_UPDATES_ACTION_INSTALL;

                                if ( ! empty( $needsupgrade ) && ! empty( $versiontext ) ) {
                                    $update_config['tasks'] = '<small>' . TEXT_THIS_FILE_UPDATE_CREATOR_UPDATE_INSTALLED_VERSION . ' ' . $versiontext . '</small><br/>' . $update_config['tasks'];
                                }

                                if ( empty( $sameversion ) ) {
                                    $update_config['tasks'] = str_replace( 'install', '<a class="btn btn-sm btn-outline-secondary mt-2 ml-2" href="zipur_toolbox.php?zipinstall=' . $installhash . '&installstep=' . $installstep . '">' . $installbuttontext . '</a>', $update_config['tasks'] );
                                } else {
                                    $update_config['tasks'] = str_replace( 'install', '<a class="btn btn-sm btn-outline-secondary mt-2 ml-2" href="zipur_toolbox.php?zipinstall=' . $installhash . '&installstep=' . $installstep . '">' . TEXT_UPDATES_ACTION_REINSTALL . '</a>', $update_config['tasks'] );
                                }

                                $update_config['tasks'] = str_replace( 'remove', '<a class="btn btn-sm btn-outline-secondary mt-2 ml-2" href="zipur_toolbox.php?zipremove=' . $installhash . '">' . TEXT_UPDATES_ACTION_UNINSTALL . '</a>', $update_config['tasks'] );

                                $update_config['tasks'] .= '<button class="btn btn-sm btn-outline-secondary mt-2 ml-2"  onclick="zipDeleteThisUpdate(\'' . $installhash . '\');">' . TEXT_UPDATES_ACTION_DELETE . '</button>';

                                $update_config['tasks'] = str_replace( '|', '', $update_config['tasks'] );

                                $installthis   = 0;
                                $updatemessage = '';

                                if ( ! empty( $zipinstall ) ) {
                                    if ( $zipinstall == $installhash ) {
                                        $installthis            = 1;
                                        $remembertasks          = $update_config['tasks'];
                                        $update_config['tasks'] = TEXT_UPDATES_ACTION_INSTALLING . ' ...';
                                    }
                                } else if ( ! empty( $zipdelete ) ) {
                                    if ( $zipdelete == $installhash ) {
                                        $update_config['tasks'] = TEXT_UPDATES_ACTION_REMOVING . ' ...';
                                        $installthis            = 2;
                                    }
                                } else if ( ! empty( $zipremove ) ) {
                                    if ( $zipremove == $installhash && ! empty( $update_uninstall_actions ) ) {
                                        $update_config['tasks']       = TEXT_UPDATES_ACTION_UNINSTALL . ' ...';
                                        $update_config['description'] .= '<br/><br/>' . TEXT_UPDATES_REMOVING_PACKAGE . ' ...';

                                        $updatemessage = zipShowUpdateOutline( $update_uninstall_actions, true, 'uninstall' );

                                    }
                                }

                                $zipfile = '<a href="zipur_toolbox.php?zipzip=' . $installhash . '&zipupdatecreator=1&updatebuildstep=1&updatefolder=' . $folder . '"><i class="fas fa-file-archive"></i></a> ';

                                if ( empty( $update_config['update_version'] ) ) {
                                    $update_config['update_version'] = '';
                                }

                                $foldertext = str_replace( '_' . str_replace( '.', '_', $update_config['update_version'] ), '', $folder );

                                zipurRow( $zipfile . $foldertext . '<br/>' .
                                          $update_config['update_version'], $update_config['description'], '<span class="' . $versioncolor1 . '">' . $reqver . '</span>', '<span class="' . $versioncolor2 . '">' . $maxver . '</span>', $update_config['tasks'] );

                                if ( ! empty( $updatemessage ) ) {
                                    zipurRow( '', $updatemessage . '<br/>' . TEXT_THIS_UPDATE_REMOVED );
                                }

                                if ( $installthis == 1 ) {

                                    //skip empty pre-install
                                    if ( $installstep == 2 && empty( $update_pre_install_actions ) ) {
                                        $installstep = 3;
                                    }
                                    //skip empty post-install
                                    if ( $installstep == 4 && empty( $update_post_install_actions ) ) {
                                        $installstep = 5;
                                    }

                                    $zipitemcountpre       = zipVarCheck( "zipitemcountpre", 0, "FILTER_VALIDATE_INT", 0 );
                                    $zipitemcountpost      = zipVarCheck( "zipitemcountpost", 0, "FILTER_VALIDATE_INT", 0 );
                                    $zipitemcountuninstall = zipVarCheck( "zipitemcountuninstall", 0, "FILTER_VALIDATE_INT", 0 );
                                    $extraoptouttext       = '';
                                    if ( $installstep > 1 ) {
                                        $extraoptouttext .= '<input type="hidden" name="zipitemcountpre" value="' . $zipitemcountpre . '">';
                                        $extraoptouttext .= '<input type="hidden" name="zipitemcountpost" value="' . $zipitemcountpost . '">';
                                        $extraoptouttext .= '<input type="hidden" name="zipitemcountuninstall" value="' . $zipitemcountuninstall . '">';
                                    }
                                    if ( ! empty( $zipitemcountpre ) ) {
                                        for ( $i = 1; $i <= $zipitemcountpre; $i ++ ) {
                                            $thiszipoptional = zipVarCheck( "zipoptionalpre{$i}", 0, "FILTER_VALIDATE_INT", 0 );
                                            if ( ! empty( $thiszipoptional ) ) {
                                                $extraoptouttext .= '<input type="hidden" name="zipoptionalpre' . $i . '" value="1">';
                                            }
                                        }
                                    }
                                    if ( ! empty( $zipitemcountpost ) ) {
                                        for ( $i = 1; $i <= $zipitemcountpost; $i ++ ) {
                                            $thiszipoptional = zipVarCheck( "zipoptionalpost{$i}", 0, "FILTER_VALIDATE_INT", 0 );
                                            if ( ! empty( $thiszipoptional ) ) {
                                                $extraoptouttext .= '<input type="hidden" name="zipoptionalpost' . $i . '" value="1">';
                                            }
                                        }
                                    }
                                    if ( ! empty( $zipitemcountuninstall ) ) {
                                        for ( $i = 1; $i <= $zipitemcountuninstall; $i ++ ) {
                                            $thiszipoptional = zipVarCheck( "zipoptionaluninstall{$i}", 0, "FILTER_VALIDATE_INT", 0 );
                                            if ( ! empty( $thiszipoptional ) ) {
                                                $extraoptouttext .= '<input type="hidden" name="zipoptionaluninstall' . $i . '" value="1">';
                                            }
                                        }
                                    }

                                    if ( $installstep == 1 ) {
                                        //PREVIEW
                                        $message = '<form action="zipur_toolbox.php" method="post">';
                                        $message .= '<p>' . TEXT_THIS_UPDATE_WILL . '</p>' . PHP_EOL;
                                        $message .= '<ol>' . PHP_EOL;
                                        $message .= '<li>' . TEXT_THIS_UPDATE_PRE_TITLE . PHP_EOL;
                                        /** @var array $update_pre_install_actions */
                                        $message .= zipShowUpdateOutline( $update_pre_install_actions, false, 'pre' );
                                        $message .= '</li>' . PHP_EOL;
                                        $message .= '<li>' . TEXT_THIS_UPDATE_FILE_UPDATES . PHP_EOL;
                                        $message .= '</li>' . PHP_EOL;
                                        $message .= '<li>' . TEXT_THIS_UPDATE_POST_TITLE . PHP_EOL;
                                        /** @var array $update_post_install_actions */
                                        $message .= zipShowUpdateOutline( $update_post_install_actions, false, 'post' );
                                        $message .= '</li>' . PHP_EOL;
                                        $message .= '</ol>' . PHP_EOL;
                                        $message .= '<input type="hidden" name="zipinstall" value="' . $installhash . '"/>';
                                        $message .= '<input type="hidden" name="installstep" value="2"/>' . $extraoptouttext;
                                        zipurRow( '', $message . '<br/><br/><button class="btn btn-sm btn-outline-primary mt-2 ml-2">' . TEXT_THIS_UPDATE_CONTINUE . ' --&gt;</button></form>' );

                                    } else if ( $installstep == 2 ) {

                                        //PRE-INSTALL
                                        $message = '<form action="zipur_toolbox.php" method="post">';
                                        $message .= zipShowUpdateOutline( $update_pre_install_actions, true, 'pre' );
                                        $message .= '<input type="hidden" name="zipinstall" value="' . $installhash . '"/>';
                                        $message .= '<input type="hidden" name="installstep" value="3"/>' . $extraoptouttext;
                                        zipurRow( '', $message . '<br/><br/><button class="btn btn-sm btn-outline-primary mt-2 ml-2">' . TEXT_THIS_UPDATE_CONTINUE . ' --&gt;</button></form>' );

                                    } else if ( $installstep == 3 ) {

                                        $message = '<form action="zipur_toolbox.php" method="post">';
                                        $message .= '<input type="hidden" name="zipinstall" value="' . $installhash . '"/>';
                                        $message .= '<input type="hidden" name="installstep" value="4"/>' . $extraoptouttext;
                                        //PLACE FILES/CREATE FOLDERS
                                        zipurRow( '', $message . '<br/><br/><button class="btn btn-sm btn-outline-primary mt-2 ml-2">' . TEXT_THIS_UPDATE_CONTINUE . ' --&gt;</button><br/><br/></form>' );

                                    } else if ( $installstep == 4 ) {

                                        //POST_INSTALL
                                        $message = '<form action="zipur_toolbox.php" method="post">';
                                        $message .= zipShowUpdateOutline( $update_post_install_actions, true, 'post' );
                                        $message .= '<input type="hidden" name="zipinstall" value="' . $installhash . '"/>';
                                        $message .= '<input type="hidden" name="installstep" value="5"/>' . $extraoptouttext;
                                        zipurRow( '', $message . '<br/><br/><button class="btn btn-sm btn-outline-primary mt-2 ml-2">' . TEXT_THIS_UPDATE_CONTINUE . ' --&gt;</button></form>' );

                                    } else if ( $installstep == 5 ) {

                                        //COMPLETED
                                        $message    = TEXT_THIS_UPDATE_FINISHED;
                                        $deletelink = ( ! empty( TEXT_THIS_UPDATE_DELETE_UPDATE_FILES ) ) ? '<br/><br/><a class="btn btn-sm btn-outline-secondary mt-2 ml-2" href="zipur_toolbox.php?zipdelete=' . $installhash . '">' . TEXT_THIS_UPDATE_DELETE_UPDATE_FILES . '</a>' : '';
                                        zipurRow( '', '<h3>' . TEXT_THIS_UPDATE_COMPLETED . '</h3>' . $message . $deletelink );

                                    }
                                }

                                if ( ! empty( $zipdelete ) ) {
                                    if ( $zipdelete == $installhash ) {
                                        if ( $installthis == 2 ) {
                                            zipurRow( '', TEXT_THIS_UPDATE_REMOVED . ' : ' . $thisfolder );
                                            zipDeleteDirectory( $thisfolder );
                                            echo '<script>window.location.reload();</script>';

                                        }
                                    }
                                }

                                if ( ( ! empty( $versionstatus[0] ) && ! empty( $versionstatus[1] ) && $installthis == 1 && $installstep == 3 ) ) {
                                    zipur_loop_files( $thisfolder, '', - 1, '', $installthis, $folder );
                                }
                            }
                        } else if ( strpos( $thisfolder, '_zip.zip' ) !== false ) {
                            //clean up zip files generated by downloader
                            unlink( $thisfolder );

                        }
                    }
                ?>
                </tbody>
            </table>
        </div>
        <hr/>
        <p><?php echo TEXT_UPDATES_DIRECTORY . ' ' . $updatesBaseDirectory; ?></p>
        <?php
    }

?>


<div id="id01" class="modal">
    <span onclick="document.getElementById('id01').style.display='none'" class="close"
          title="Close Modal">&times;</span>
    <form class="modal-content" action="zipur_toolbox.php">
        <div class="container">
            <h1><?php echo TEXT_UPDATES_DELETE; ?></h1>
            <p><?php echo TEXT_THIS_UPDATE_DELETEE_CONFIRM; ?></p>

            <div class="clearfix">
                <button type="button" class="cancelbtn" onClick="document.getElementById('id01').style.display='none';">
                    <?php echo TEXT_UPDATES_CANCEL; ?>
                </button>
                <button type="button" class="deletebtn" onClick="zipDeleteThisUpdateNow();"><?php echo TEXT_UPDATES_DELETE; ?></button>
            </div>
        </div>
    </form>
</div>

<?php
    require 'includes/template_bottom.php';
    require 'includes/application_bottom.php';
?>
